@@ -25,16 +25,17 @@
 #' }
 #' 
 #' @details
-#' Note that theta (`th`) is a p-dimensional vector, `h` is a K-dimensional vector and K \eqn{\geq}{<=} p
+#' Note that theta (`th`) is a p-dimensional vector, `h` is a K-dimensional vector and K \eqn{\geq}{>=} p
 #' 
 #' 
 #' @param th        p x 1 parameter vector to evaluate the AEL function at
-#' @param h         User-defined moment-condition function. Note that output should be an (n-1) x K matrix where K is necessarily \eqn{\geq}{<=} p
+#' @param h         User-defined moment-condition function. 
+                 #' Note that output should be an n x K matrix where K is necessarily \eqn{\geq}{>=} p. 
+                 #' Input format for h should be (zi, th) were zi corresponds to the ith observation's data and th is the parameter vector
 #' @param lam0      Initial vector for Lagrange multiplier lambda
 #' @param a         Positive scalar adjustment constant
-#' @param z         (n-1) x d data matrix. Note that \eqn{\{z_i\}_{i=1}^{n-1}} is a sequence of d-dimensional data vectors
+#' @param z         n x d data matrix. Note that \eqn{\{z_i\}_{i=1}^{n}} is a sequence of d-dimensional data vectors
 #' @param iters     Number of iterations using Newton-Raphson for estimation of lambda. Default: `500`
-#' @param returnH   Whether to return calculated values of h, H matrix and lambda. Default: `FALSE
 #'
 #' @return A numeric value for the Adjusted Empirical Likelihood function 
 #' computed evaluated at a given theta value
@@ -45,7 +46,7 @@
 #' 
 #' @author Weichang Yu, Jeremy Lim
 #' @references Chen, J., Variyath, A. M., and Abraham, B. (2008), “Adjusted Empirical
-#' Likelihood and its Properties,” Journal of Computational and Graphical
+#' Likelihood and its Properties”, Journal of Computational and Graphical
 #' Statistics, 17, 426–443. Pages 2,3,4,5,6,7 \doi{doi:10.1198/106186008X321068}
 #' 
 #' @examples
@@ -54,7 +55,7 @@
 #' x     <- runif(30, min = -5, max = 5)
 #' vari  <- rnorm(30, mean = 0, sd = 1)
 #' y     <- 0.75 - x + vari
-#' z <- cbind(x, y)
+#' z     <- cbind(x, y)
 #'
 #' lam0  <- matrix(c(0,0), nrow = 2)
 #' th    <- matrix(c(0.8277, -1.0050), nrow = 2)
@@ -64,14 +65,14 @@
 #' iters <- 10
 #' 
 #' # Specify moment condition functions for linear regression
-#' h <- function(z, th) {
-#'     xi      <- z[1]
-#'     yi      <- z[2]
+#' h <- function(zi, th) {
+#'     xi      <- zi[1]
+#'     yi      <- zi[2]
 #'     h_zith  <- c(yi - th[1] - th[2] * xi, xi*(yi - th[1] - th[2] * xi))
 #'     matrix(h_zith, nrow = 2)
 #' }
 #' result <- compute_AEL(th, h, lam0, a, z, iters)
-compute_AEL <- function(th, h, lam0, a, z, iters = 500, returnH = FALSE) {
+compute_AEL <- function(th, h, lam0, a, z, iters = 500) {
     
     p <- ncol(z)
     n <- nrow(z) + 1
@@ -90,14 +91,6 @@ compute_AEL <- function(th, h, lam0, a, z, iters = 500, returnH = FALSE) {
     H_Zth <- rbind(H_Zth, t(h_znth)) # Last row of H is h(zn,th)
     res <- compute_AEL_Rcpp_inner_prez(th, H_Zth, lam0, a, z, iters)
     
-    if (!returnH) {
-        res$log_AEL
-    } else {
-        return(list(
-            "log_AEL" = res[[1]],
-            "lambda" = res[[2]],
-            "h_arr" = array(t(H_Zth), dim = c(1, ncol(H_Zth), n)),
-            "H" = H_Zth
-        ))
-    }
+    # Return value
+    res$log_AEL
 }
\ No newline at end of file
